Registrácia nového člena Motoride Klubu: motoride.sk
Description: Stránka venovaná všetkým priaznivcom motoriek...
Keywords: motorky, obrázky motoriek, motoride, chat, kalendár podujatí, články, testy, videá, motorcycle pictures, bikes, novinky, diskusia, ukradnuté motorky

ISSN 1336-6491 | Online: 1146 | Redakcia

motoride.sk :: Články | Videá | Tipy | Foto | Klub | Inzercia | Firmy | Fórum | Kalendár | Jawa okolo sveta

login: heslo:
Neodhlasovať

## Anketa: Zapojíš sa do kampane Pozri dvakrát, zachrániš život!?
Spolu odpovedi: 5474
áno, určite ju podporím: 53% (2925)
nie, nezaujalo ma to: 47% (2549)
## Pre vás: Povinné zmluvné poistenie - vyber si najlepšiu cenu! | # Registrácia nového člena Motoride Klubu Čo získate registráciu v Motoride Klube ? Možnosť pridávať články, tipy na výlet, body záujmu, videá a fotografie. Prezentáciu seba a svojho stroja na týchto stránkach Možnosť spoznať motorkárov, ktorí majú napr. rovnakú motorku, prípadne sú z Vášho blízkeho okolia. Zapojit sa do diskusií a chatu. Modrou farbou označené políčka sú povinné!
Login: |
| - zvoľ si login - môže obsahovať len písmená bez diakritiky a číslice.
Meno: |  | Priezvisko: |
| - zadaj skutočné meno a priezvisko. Po prihlásení si môžeš sám nastaviť utajenie priezviska alebo aj celého mena.
Pohlavie: |
E-mail: |
| - zadaj platný email kam ti pošleme vygenerované heslo.
Krajina: |
PSČ / Mesto: | - Mesto zadaj aj s použitím diakritiky.
Motoštýl: | Vyber motoštýl, ktorý ťa najviac oslovuje - Nejde o to akú máš teraz motorku, ale čo ťa láka najviac. (Cestovanie, bahnenie, jazda na jogurte alebo len relax na kávičke)
| Som:
Motorka: |
Niečo o sebe:
Ak chceš napíš niečo o sebe:
Ochrana pred spamom. Zadaj do políčka nižšie 5 znakov ktoré vidíš na obrázku.
Znaky Reťazec obsahuje iba ČÍSLICE a VEĽKÉ PÍSMENÁ.
Stlačením tlačidla Registrovať potvrdzujem že som si pozorne prečítal Podmienky poskytovania služieb motoride.sk a ochrana osobných údajov.
| ## Redakčné videá: ## Štefan Svitko testuje tlmiče na Dakar- KTM... 10:07 ## Štefan Svitko - rozhovor pred Dakarom 2015... 13:15 ## Sony Xperia Freestyle X-Night 2014 - zostrih... 03:06 ▼ Zobraz viac ▼ ## KTM Freeride E-XC 2015 - Prvá testovacia... 03:21 ## Suzuki RM-Z450 a RM-Z250 2015 02:55 ## Moto Guzzi V7 Racer s haZard zvukom - ladené... 00:53 ## Neprehliadnite: 22.10.2014 - datadive [Testy a predstavenia - Vyskúšali sme] ### Honda CTX 700 DCT ABS 2014 - Kam to bude, pane? Viac » 06.11.2014 - mikulec [Testy a predstavenia - Vyskúšali sme] ### Beta RR 300 a 350 EFI na motokrosovom preteku Viac » 10.11.2014 - zeON [Testy a predstavenia - Test] ### Prvý test: Honda VFR800X Crossrunner 2015 - Pohodlie, šport a tak trochu adventure Viac » ## Tričko Motoride.sk Tričko a šiltovka pre všetkých priaznivcov servera MotoRide... Zasielanie tovaru obnovené! Šiltovka motoride.sk. ## Vtip Pridal: demmoo Včera som pozeral porno. V tom prišla mama. Musel som si to trikrát pretočiť, lebo som nechcel veriť, že to je ona. Ďalšie vtipy »